@@ -2,6 +2,10 @@
         library.dynam("cts", pkg, lib)
 
 car_control <- function(fty=1, n.ahead=10, trace=FALSE, ari=TRUE, vri=FALSE, vr=0, pfi="MAPS",ccv="CTES", lpv=TRUE, scc=TRUE,  nit=40, opm=1, rgm=1, req=0.5, con=1.0e-5, rpe=1.0, ivl=1.0e-2, fac=1.0e1, stl=1.0e-5, sml=1.0e2, gtl=1.0e5, kst=TRUE, fct=TRUE){
+tmp <- .Machine
+tmp1 <- c(tmp$double.neg.eps, tmp$double.base, tmp$double.digits, tmp$double.min.exp, tmp$double.xmin)
+names(tmp1) <- NULL
+write.table(file="machine.txt", tmp1, row.names=FALSE, col.names=FALSE)
   RET <- list(fty=fty, n.ahead=n.ahead, trace=trace, ari=ari, vri=vri, vr=vr, pfi=pfi,ccv=ccv, lpv=lpv, scc=scc, nit=nit, opm=opm, rgm=rgm, req=req, con=con, rpe=rpe, ivl=ivl, fac=fac, stl=stl, sml=sml, gtl=gtl, kst=kst, fct=fct)
   class(RET) <- c("car_control")
   RET
@@ -36,7 +40,7 @@ function(x, y=NULL, scale=1.5, order=3, ctrl=car_control())
     if (pfi==0) stop("Invalid PFI option:",pfi)
 #    scale <- sca
     if (scale <= csz) stop("Invalid SCALE value:",scale)
-    if (order <= 0 || order > 20) stop("Invalid ARP value:", order)
+    if (order <= 0 || order > 20) stop("Model order value must between 1 and 20")
 
     if (ari==FALSE) ari <- 0
     if (ari==TRUE){
@@ -147,7 +151,17 @@ function(x, y=NULL, scale=1.5, order=3, ctrl=car_control())
         zpar <- .Fortran("loop",
                 ss=double(nit+1),
                 bit=as.double(matrix(0, nit+1, 22)),
-           package="cts")
+                errno=integer(1),  package="cts")
+        if(zpar$errno == 1) stop("ROOT WITH POSITIVE REAL PART, WHICH WAS CALLED IN loop.f")
+        else if(zpar$errno == 2) stop("ERROR IN LAPACK SUBROUTINE zgesv, WHICH WAS CALLED IN cinvert.f")
+        else if(zpar$errno == 3) stop("PROGRAM FAILS IN SLICE ROUTINE LYBSC, WHICH WAS CALLED IN resg1d.f")
+        else if(zpar$errno == 30) stop("PROGRAM FAILS IN SLICE ROUTINE LYBSC, WHICH WAS CALLED IN resg1dpre.f")
+        else if(zpar$errno == 31) stop("PROGRAM FAILS IN SLICE ROUTINE LYBSC, WHICH WAS CALLED IN resg1dpre1.f")
+        else if(zpar$errno == 4) stop("PROGRAM FAILS IN SLICE ROUTINE MEPAD, WHICH WAS CALLED IN resg1d.f")
+        else if(zpar$errno == 40) stop("PROGRAM FAILS IN SLICE ROUTINE MEPAD, WHICH WAS CALLED IN resg1dpre.f")
+        else if(zpar$errno == 51) stop("PROGRAM FAILS IN SUBROUTINE DPOTRF, WHICH WAS CALLED IN revg1.f")
+        else if(zpar$errno == 52) stop("PROGRAM FAILS IN SUBROUTINE DPOTRI, WHICH WAS CALLED IN revg1.f")
+        else if(zpar$errno == 6) stop("PROGRAM FAILS IN SUBROUTINE DIVC , WHICH WAS CALLED IN dpca.f")
         neff <- zpar$ss > 0
         zpar$tnit <- seq(0, sum(neff))
         zpar$ss <- zpar$ss[neff]
